@@ -11,7 +11,7 @@ sub new {
 }
 
 sub calculate {
-	 my (@a, $n, $u0, $C) = @_;
+	 my ($self, @a, $n, $u0, $C) = @_;
 
 	$C = @a[$n];
 	
